import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:material_design_icons_flutter/material_design_icons_flutter.dart';
import 'package:materialdesignlogo/assets/style.dart';
import 'package:materialdesignlogo/materialdesignlogo.dart';
import 'package:readme/readme.dart';

Future<void> main(List<String> args) async {
  final info = getPackageInfo();

  final shiledProps = await ShieldProps.read();

  final readme = new Readme()
    ..packageName = info.name
    ..description = info.description
    ..license = args.length > 0 ? args.first : 'MIT'
    ..example = await getExample()
    ..shields = compileShields(shiledProps);
  stdout.write(readme);
//  runApp(MyApp());
}

Color backgroundColor = Colors.red[50];

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  int index = 0;

  @override
  Widget build(BuildContext context) => MaterialApp(
        title: 'Material Design Logo Sample',
        debugShowCheckedModeBanner: false,
        home: Scaffold(
          backgroundColor: backgroundColor,
//        appBar: AppBar(title: MdiLogo.materialDesignLogo(),),
          body: IndexedStack(
            index: index,
            children: [
//              SliverScreen(combinedWidgets()),
//              SliverScreen(shapedWidgets()),
//              SliverScreen(iconScreenWidgets()),
//              SliverScreen(autoTextScreen()),
//              SliverScreen(textList()),
            ],
          ),
          bottomNavigationBar: BottomNavigationBar(
              backgroundColor: backgroundColor,
              onTap: (i) {
                setState(() {
                  index = i;
                });
              },
              type: BottomNavigationBarType.fixed,
              items: [
                BottomNavigationBarItem(
                  title: Text("Combine"),
                  icon: Icon(MdiIcons.shape),
                ),
                BottomNavigationBarItem(
                  title: Text("Shape"),
                  icon: Icon(MdiIcons.shape),
                ),
                BottomNavigationBarItem(
                  title: Text("Icon"),
                  icon: Icon(MdiIcons.shapeSquarePlus),
                ),
                BottomNavigationBarItem(
                  title: Text("AutoTShape"),
                  icon: Icon(MdiIcons.appsBox),
                ),
                BottomNavigationBarItem(
                  title: Text("Text"),
                  icon: Icon(MdiIcons.text),
                ),
              ]),
        ),
      );
}

class SliverScreen extends StatelessWidget {
  const SliverScreen(
    this.logos,
  );

  final List<Widget> logos;

  @override
  Widget build(BuildContext context) {
    var flexRadius = Radius.elliptical(62, 62);
    var flexColor = Colors.red;
    return Container(
      child: CustomScrollView(
        slivers: <Widget>[
          SliverAppBar(
              backgroundColor: backgroundColor,
              elevation: 2,
              pinned: true,
              collapsedHeight: 70,
              floating: false,
              expandedHeight: 170.0,
              flexibleSpace: FlexibleSpaceBar(
                centerTitle: true,
                background: Container(
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.only(
                        bottomRight: flexRadius,
                        bottomLeft: flexRadius,
                      ),
                      gradient: MdiStyle.materialSliverGradient1(flexColor),
                      backgroundBlendMode: BlendMode.luminosity),
                ),
                title: MdiLogo.combineMdiSample(),
              )),
          SliverList(
              delegate: SliverChildBuilderDelegate(
                  (context, index) => Container(child: logos[index]),
                  childCount: logos.length)),
        ],
      ),
    );
  }
}
